<?php

$LANG = array(

#header.php
'MENU'					=> 'Menú',
'HOME'					=> 'Inicio',
'GOTO_CONTENT'			=> 'Ir al contenido',
'GOTO_MENU'				=> 'Ir al men&uacute;',
'COMMENTS_ATOM_FEEDS'	=> 'Hilo Atom de los comentarios',
'COMMENTS_RSS_FEEDS'	=> 'Hilo Rss de los comentarios',
'COMMENTS'				=> 'Comentarios',
'ARTICLES_RSS_FEEDS'	=> 'Hilo Rss de los art&iacute;culos',
'ARTICLES'				=> 'Art&iacute;culos',

# sidebar.php
'CATEGORIES' 			=> 'Categor&iacute;as',
'LATEST_ARTICLES'		=> 'Ultimos art&iacute;culos',
'LATEST_COMMENTS'		=> 'Ultimos comentarios',
'ARCHIVES'				=> 'Archivos',

# footer.php
'POWERED_BY'			=> 'Generado por',
'PLUXML_DESCRIPTION'	=> 'Blog o Cms sin bases de datos',
'IN'					=> 'en',
'ADMINISTRATION'		=> 'Administraci&oacute;n',
'GOTO_TOP'				=> 'Volver Inicio de p&aacute;gina',
'TOP'					=> 'Inicio de p&aacute;gina',

# erreur.php
'ERROR'					=> 'Se ha detectado un error',
'BACKTO_HOME'			=> 'Volver a la p&aacute;gina de Inicio',

# common
'WRITTEN_BY'			=> 'Escrito por',
'CLASSIFIED_IN'			=> 'Ordenado en',
'TAGS'					=> 'Palabras claves',

# commentaires.php
'SAID'					=> 'ha dicho',
'WRITE_A_COMMENT'		=> 'Escribir un comentario',
'NAME'					=> 'Nombre',
'WEBSITE'				=> 'Sitio web (opcional)',
'EMAIL'					=> 'Email (opcional)',
'COMMENT'				=> 'Comentario',
'CLEAR'					=> 'Borrar',
'SEND'					=> 'Enviar',
'COMMENTS_CLOSED'		=> 'Comentarios cerrados',
'ANTISPAM_WARNING'		=> 'Chequeo anti-spam',

'REPLY'					=> 'Contestación',
'REPLY_TO'				=> 'Contestación',
'CANCEL'				=> 'Cancelar',

);

?>